::: nyckel.ClassificationLabel
    options:
        show_source: true
        members: false

::: nyckel.ClassificationPrediction
    options:
        show_source: true
        members: false

::: nyckel.ClassificationAnnotation
    options:
        show_source: true
        members: false

::: nyckel.TabularFunctionField
    options:
        show_source: true
        members: false

::: nyckel.ImageClassificationSample
    options:
        show_source: true
        members: false

::: nyckel.TextClassificationSample
    options:
        show_source: true
        members: false

::: nyckel.TabularClassificationSample
    options:
        show_source: true
        members: false
